@@ -4,6 +4,8 @@ import os
 from dotenv import load_dotenv
 from jinja2 import Environment, PackageLoader, select_autoescape
 
+PACKAGE_PATH = os.path.dirname(__file__)
+
 load_dotenv(override=True)
 
 logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
@@ -14,6 +16,8 @@ JINJA_ENV = Environment(loader=PackageLoader("fhir_cli"), autoescape=select_auto
 # FHIR
 
 FHIR_API_URL = os.environ.get("FHIR_API_URL", "http://localhost:8080/fhir")
+FHIR_API_USER = os.environ.get("FHIR_API_USER")
+FHIR_API_PASSWORD = os.environ.get("FHIR_API_PASSWORD")
 FHIR_COLUMN_NAME = "fhir"
 
 # OMOP
@@ -42,7 +46,7 @@ POSTGRES_HOST = os.environ.get("POSTGRES_HOST", "localhost")
 POSTGRES_PORT = int(os.environ.get("POSTGRES_PORT", 5432))
 POSTGRES_DB = os.environ.get("POSTGRES_DB", "postgres")
 POSTGRES_USER = os.environ.get("POSTGRES_USER", "postgres")
-POSTGRES_PASSWORD = os.environ.get("POSTGRES_PASSWORD", "postgres")
+POSTGRES_PASSWORD = os.environ.get("POSTGRES_PASSWORD", "secret")
 POSTGRES_SERVER_NAME = os.environ.get("POSTGRES_SERVER_NAME", "postgres")
 
 # Functions
